Package: CrcBiomeScreen
Title: An R package for colorectal cancer screening and microbiome
        analysis
Version: 1.1.6
Authors@R: c(person("Chengxin", "Li",
                  email = "ngzh5554@leeds.ac.uk",
                  role = c("cre", "aut"),
                  comment = c(ORCID = "0009-0004-0840-9027")),
            person("Rishabh", "Bezbaruah",
                  email = "rishabhbezbaruah@gmail.com",
                  role = c("aut")),
            person("Henry", "Wood",
                  email = "h.m.wood@leeds.ac.uk",
                  role = c("aut")),
            person("Arief", "Gusnanto",
                  email = "a.gusnanto@leeds.ac.uk",
                  role = c("aut")))
Description: A developed and benchmarked reproducible machine learning framework
  for microbiome-based colorectal cancer (CRC) screening. By systematically 
  evaluating normalization strategies, taxonomic resolutions, and class imbalance
  handling. This R package allows users to apply the full pipeline or selectively 
  run specific components depending on their analytical needs. It establishes a 
  scalable foundation for developing interpretable microbiome-based screening 
  tools to support early CRC detection. This approach could be easily implemented 
  in a national screening programme, to improve early detection rates for 
  this disease.
License: MIT + file LICENSE
biocViews: Software, Microbiome, Metagenomics, Classification,
        Normalization, Visualization
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
Config/testthat/edition: 3
Depends: R (>= 4.3.0)
Imports: rlang, methods, dplyr, doFuture, doParallel, foreach, future,
        future.apply, pROC, progress, progressr, stats, tibble, tidyr,
        TreeSummarizedExperiment, ggplot2, GUniFrac, magrittr,
        parallel, withr, SummarizedExperiment, caret, ranger, utils,
        graphics, grDevices
Suggests: rstatix, MASS, mgcv, ggplotify, ggpubr, ggrepel, ggtree,
        glmnet, Matrix, microbiome, phyloseq, vegan, gt, testthat (>=
        3.0.0), BiocManager, devtools, knitr, rmarkdown, BiocStyle,
        curatedMetagenomicData, xgboost
VignetteBuilder: knitr
LazyData: false
URL: https://github.com/omicsForestry/CrcBiomeScreen
BugReports: https://github.com/omicsForestry/CrcBiomeScreen/issues
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/CrcBiomeScreen
git_branch: devel
git_last_commit: e98e95f
git_last_commit_date: 2026-07-22
Repository: Bioconductor 3.24
Date/Publication: 2026-08-10
NeedsCompilation: no
Packaged: 2026-08-10 21:08:31 UTC; biocbuild
Author: Chengxin Li [cre, aut] (ORCID: <https://orcid.org/0009-0004-0840-9027>),
  Rishabh Bezbaruah [aut],
  Henry Wood [aut],
  Arief Gusnanto [aut]
Maintainer: Chengxin Li <ngzh5554@leeds.ac.uk>
