#' Thomas 2018 relative abundance dataset
#'
#' A relative abundance dataset derived from curatedMetagenomicData and included
#' for package examples.
#' 2021-03-31.ThomasAM_2018a.relative_abundance:
#' Formal class 'TreeSummarizedExperiment' from
#' package "TreeSummarizedExperiment" with 14 slots.
#'
#' @format A named list containing relative abundance objects for demonstration.
#' @source curatedMetagenomicData
"Thomas_2018_RelativeAbundance"
