#' NHSBCSP screening dataset
#'
#' A toy screening dataset derived from the NHS Bowel Cancer Screening Programme.
#'
#' @format A data frame containing sample-level metadata and abundance data.
#' The first two columns(index and grp) store sample identifiers and metadata, and the remaining
#' columns contain microbial abundance features used for package examples and
#' demonstrations.(2252 obs. of  647 variables).
#' @source NHS Bowel Cancer Screening Programme
"NHSBCSP_screeningData"
