% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CreateCrcBiomeScreenObject.R
\docType{class}
\name{CrcBiomeScreen-class}
\alias{CrcBiomeScreen-class}
\title{CrcBiomeScreen Class}
\value{
A A \code{CrcBiomeScreen} object. object.
}
\description{
An S4 container for CRC microbiome screening data, including abundance
matrices, taxonomy, sample metadata, and model results.
}
\section{Slots}{

\describe{
\item{\code{AbsoluteAbundance}}{Absolute abundance matrix.}

\item{\code{TaxaData}}{Taxonomy annotation data frame.}

\item{\code{SampleData}}{Sample metadata (must include number_reads if relative
abundance is used).}

\item{\code{RelativeAbundance}}{Relative abundance matrix.}

\item{\code{TaxaLevelData}}{Optional genus-level summary.}

\item{\code{NormalizedData}}{Normalized abundance data.}

\item{\code{ValidationData}}{Optional validation dataset.}

\item{\code{ModelData}}{Processed training/testing data.}

\item{\code{ModelResult}}{Fitted model objects.}

\item{\code{EvaluateResult}}{List of evaluation metrics (RF, XGBoost, etc.).}

\item{\code{PredictResult}}{Predictions for external data.}
}}

